# MicceriRD
See https://pdfs.semanticscholar.org/2903/180261ee0d99a27cfe85cde9cf4af74923c6.pdf

Micceri, Theodore, 1989. The Unicorn, The Normal Curve, and Other Improbable Creatures. Psychological Bulletin 1989, Vol. 105. No. 1, 156-166

Contains both sampling functions and distributions - all in the form of Numpy arrays.

MicceriRD.Sampling.Name_of_distribution(k,n) for random sample array of k samples of n size.

MicceriRD.Name_of_distribution for distribution array itself.
